==> vue-ui-0.10.44.tgz: package/src/config/uiComponentConfig.ts <==
import {MonthListItem} from "@/components/UiPeriodSearchModel"
import browserUtil from "@/util/browserUtil"

export type ScrollType = 'PAGE' | 'MORE' | 'INFINITE'

export type MessageFunction = (args: unknown[]) => string

export type UiComponentConfig = {
  fileUrlPrefix: string
  blankImageUrl: string
  errorImageUrl: string
  alertRequired: string
  alertNumberOnly: string
  alertMinCharCount: MessageFunction
  alertMaxCharCount: MessageFunction
  currencySymbolBefore: string
  currencySymbolAfter: string
  pointSymbolAfter: string
  inputQtyChangeButtonCaption: string
  loadingOverlayColor: string
  loadingOverlayStyle: 'spinner' | 'dots' | 'bars'
  scrollListDefaultScrollType: ScrollType
  scrollListDefaultScrollTypeMobile?: ScrollType
  scrollListDefaultScrollTypePc?: ScrollType
  scrollListMoreCaption: string
  scrollListMoreButtonIcon: string
  scrollListMoreButtonDirection: 'left' | 'right' | 'top'
  periodSearchMonthList: MonthListItem[]
  periodSearchAllCaption: string
  processStepIconClass: string
  imagePreventCopy: boolean
  useSelectCustomOption: boolean
  srcsetMaxResolution: number
}

export const uiComponentConfig: UiComponentConfig = {
  fileUrlPrefix: '',
  blankImageUrl: '',
  errorImageUrl: '',
  alertRequired: 'Required',
  alertNumberOnly: 'Only numbers are allowed',
  alertMinCharCount: (args: unknown[]) => `Should be longer than ${args[0]}`,
  alertMaxCharCount: (args: unknown[]) => `Should be shorter than ${args[0]}`,
  currencySymbolBefore: '',
  currencySymbolAfter: '',
  pointSymbolAfter: 'P',
  inputQtyChangeButtonCaption: 'Change',
  loadingOverlayColor: '#3f51b5',
  loadingOverlayStyle: 'spinner',
  scrollListDefaultScrollType: 'PAGE',
  scrollListMoreCaption: 'More',
  scrollListMoreButtonIcon: 'plus',
  scrollListMoreButtonDirection: 'left',
  periodSearchMonthList: [{caption: '3M', months: 3}, {caption: '6M', months: 6}, {caption: '1Y', months: 12}],
  periodSearchAllCaption: 'All',
  processStepIconClass: 'arrow-right',
  imagePreventCopy: false,
  useSelectCustomOption: !browserUtil.isMobile(),
  srcsetMaxResolution: 3
}

/**
 * UI Component 를 설정한다.
 * @param config
 */
export const configureUiComponent = (config: Partial<UiComponentConfig>): void => {
  Object.assign(uiComponentConfig, config)
}

==> vue-ui-0.10.53.tgz: package/src/config/uiComponentConfig.ts <==
import {MonthListItem} from "@/components/UiPeriodSearchModel"
import browserUtil from "@/util/browserUtil"

export type ScrollType = 'PAGE' | 'MORE' | 'INFINITE'

export type MessageFunction = (args: unknown[]) => string

export type UiComponentConfig = {
  fileUrlPrefix: string
  blankImageUrl: string
  errorImageUrl: string
  alertRequired: string
  alertNumberOnly: string
  alertMinCharCount: MessageFunction
  alertMaxCharCount: MessageFunction
  currencySymbolBefore: string
  currencySymbolAfter: string
  pointSymbolAfter: string
  inputQtyChangeButtonCaption: string
  loadingOverlayColor: string
  loadingOverlayStyle: 'spinner' | 'dots' | 'bars'
  scrollListDefaultScrollType: ScrollType
  scrollListDefaultScrollTypeMobile?: ScrollType
  scrollListDefaultScrollTypePc?: ScrollType
  scrollListMoreCaption: string
  scrollListMoreButtonIcon: string
  scrollListMoreButtonDirection: 'left' | 'right' | 'top'
  periodSearchMonthList: MonthListItem[]
  periodSearchAllCaption: string
  processStepIconClass: string
  imagePreventCopy: boolean
  useSelectCustomOption: boolean
  srcsetMaxResolution: number
  imageQuality: number
}

export const uiComponentConfig: UiComponentConfig = {
  fileUrlPrefix: '',
  blankImageUrl: '',
  errorImageUrl: '',
  alertRequired: 'Required',
  alertNumberOnly: 'Only numbers are allowed',
  alertMinCharCount: (args: unknown[]) => `Should be longer than ${args[0]}`,
  alertMaxCharCount: (args: unknown[]) => `Should be shorter than ${args[0]}`,
  currencySymbolBefore: '',
  currencySymbolAfter: '',
  pointSymbolAfter: 'P',
  inputQtyChangeButtonCaption: 'Change',
  loadingOverlayColor: '#3f51b5',
  loadingOverlayStyle: 'spinner',
  scrollListDefaultScrollType: 'PAGE',
  scrollListMoreCaption: 'More',
  scrollListMoreButtonIcon: 'plus',
  scrollListMoreButtonDirection: 'left',
  periodSearchMonthList: [{caption: '3M', months: 3}, {caption: '6M', months: 6}, {caption: '1Y', months: 12}],
  periodSearchAllCaption: 'All',
  processStepIconClass: 'arrow-right',
  imagePreventCopy: false,
  useSelectCustomOption: !browserUtil.isMobile(),
  srcsetMaxResolution: 3,
  imageQuality: 80
}

/**
 * UI Component 를 설정한다.
 * @param config
 */
export const configureUiComponent = (config: Partial<UiComponentConfig>): void => {
  Object.assign(uiComponentConfig, config)
}
